CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_params.h Source File

CCL

ccl_params.h
Go to the documentation of this file.
1
2 #pragma once
3
8 typedef struct ccl_spline_params {
9
10 //Scale factor splines
11 double A_SPLINE_DELTA;
12 int A_SPLINE_NA;
13 double A_SPLINE_MIN;
14 double A_SPLINE_MAX;
15
16 //Mass splines
17 double LOGM_SPLINE_DELTA;
18 int LOGM_SPLINE_NM;
19 double LOGM_SPLINE_MIN;
20 double LOGM_SPLINE_MAX;
21
22 //PS a and k spline
23 int N_A;
24
25 //k-splines and integrals
26 double K_MAX_SPLINE;
27 double K_MAX;
28 double K_MIN_DEFAULT;
29 int N_K;
30
31 } ccl_spline_params;
32
33 extern ccl_spline_params * ccl_splines;
ccl_spline_params::K_MAX_SPLINE
double K_MAX_SPLINE
Definition: ccl_params.h:26
ccl_spline_params::LOGM_SPLINE_MAX
double LOGM_SPLINE_MAX
Definition: ccl_params.h:20
ccl_spline_params::A_SPLINE_NA
int A_SPLINE_NA
Definition: ccl_params.h:12
ccl_splines
ccl_spline_params * ccl_splines
Definition: ccl_core.c:27
ccl_spline_params
struct ccl_spline_params ccl_spline_params
ccl_spline_params::N_A
int N_A
Definition: ccl_params.h:23
ccl_spline_params::A_SPLINE_MAX
double A_SPLINE_MAX
Definition: ccl_params.h:14
ccl_spline_params::LOGM_SPLINE_DELTA
double LOGM_SPLINE_DELTA
Definition: ccl_params.h:17
ccl_spline_params::LOGM_SPLINE_NM
int LOGM_SPLINE_NM
Definition: ccl_params.h:18
ccl_spline_params::K_MIN_DEFAULT
double K_MIN_DEFAULT
Definition: ccl_params.h:28
ccl_spline_params::K_MAX
double K_MAX
Definition: ccl_params.h:27
ccl_spline_params
Definition: ccl_params.h:8
ccl_spline_params::N_K
int N_K
Definition: ccl_params.h:29
ccl_spline_params::A_SPLINE_DELTA
double A_SPLINE_DELTA
Definition: ccl_params.h:11
ccl_spline_params::LOGM_SPLINE_MIN
double LOGM_SPLINE_MIN
Definition: ccl_params.h:19
ccl_spline_params::A_SPLINE_MIN
double A_SPLINE_MIN
Definition: ccl_params.h:13